@@ -1,4 +1,4 @@
-/* $Id: pointers.c 27757 2008-09-08 11:12:04Z nick $ */
+/* $Id$ */
 /*
  *  Copyright (c) 2008 Nick Schermer <nick@xfce.org>
  *
@@ -42,8 +42,8 @@
 
 #define MAX_DENOMINATOR (100.00)
 
-/* this is only added to make the code compile */
-#ifdef XI_Add_DevicePresenceNotify_Major
+/* test if the required version of inputproto (1.4.2) is available */
+#if XI_Add_DevicePresenceNotify_Major >= 1 && defined (DeviceRemoved)
 #define HAS_DEVICE_HOTPLUGGING
 #else
 #undef HAS_DEVICE_HOTPLUGGING
@@ -360,7 +360,7 @@ xfce_pointers_helper_change_feedback (XDevice *device,
                 feedback.accelDenom = denom;
 
                 /* change feedback for this device */
-                XChangeFeedbackControl (xdisplay, device, mask, (XFeedbackControl *) &feedback);
+                XChangeFeedbackControl (xdisplay, device, mask, (XFeedbackControl *)(void *)&feedback);
 
                 /* done */
                 break;
